@@ -2,6 +2,7 @@
 ### 				          basic operations on repgrid objects      	        		###	 
 ###############################################################################
 
+############################# EXTRACT AND SET #################################
 
 ## S4 methods
 # overloading primitive generic "[" getter
@@ -19,14 +20,13 @@
 #' @author Mark heckmann
 #' @rdname extract-methods
 #' @include repgrid.r
-#' @keywords internal
-#' @examples \dontrun{ 
+#' @examples 
+#' 
 #'    x <- randomGrid()
 #'    x[1:4, ] 
 #'    x[ , 1:3] 
 #'    x[1:4,1:3] 
 #'    x[1,1]
-#' }
 #'
 setMethod("[", signature(x = "repgrid", i = "ANY", j="ANY"),
   function (x, i, j, ..., drop){
@@ -75,12 +75,11 @@ setMethod("[", signature(x = "repgrid", i = "ANY", j="ANY"),
 #' @author  Mark Heckmann
 #' @rdname subassign
 #' @include repgrid.r
-#' @keywords internal 
 #' @examples \dontrun{
 #'    x <- randomGrid()
 #'    x[1,1] <- 2
 #'    x[1, ] <- 4
-#'    x[,2] <- 3
+#'    x[ ,2] <- 3
 #' }
 #'
 setMethod("[<-", signature(x = "repgrid", i = "ANY", j="ANY", value="ANY"),
@@ -123,7 +122,218 @@ setMethod("[<-", signature(x = "repgrid", i = "ANY", j="ANY", value="ANY"),
 })
 
 
-#############################      CHANGE POSITIONS      #################################
+###########################  GETTER AND SETTER  ###############################
+
+
+#' get rating layer
+#'
+#' @param   x       \code{repgrid} object.
+#' @param   layer   layer to be returned.
+#' @param   names   extract row and columns names (constructs and elements).
+#' @param trim      the number of characters a row or column name is trimmed to 
+#'                  (default is \code{10}). If \code{NA} no trimming is done. Trimming
+#'                  simply saves space when displaying the output.
+#' @return          a \code{matrix} 
+#'
+#' @export
+#' @keywords internal
+#' @author Mark Heckmann
+#'
+#' @examples \dontrun{
+#'
+#'      getRatingLayer(bell2010)
+#' }
+#'
+getRatingLayer <- function(x, layer=1, names=TRUE, trim=10){
+  scores <- x@ratings[ , , layer, drop=FALSE]       # select layer
+  rm <- apply(scores, 2 , I)                        # convert array to matrix 
+  if (names) {
+    cnames.l <- getConstructNames(x)[ ,1]
+    cnames.r <- getConstructNames(x)[ ,2]
+    enames <- getElementNames(x)
+    if (!is.na(trim)){                              # trim names if prompted
+      cnames.l <- substr(cnames.l, 1, trim)
+      cnames.r <- substr(cnames.r, 1, trim)
+      enames <- substr(enames, 1, trim)
+    }                             
+    rownames(rm) <- paste(cnames.l, cnames.r, sep=" - ") 
+    colnames(rm) <- enames   
+  }
+  rm
+}
+
+
+#' Get number of constructs
+#'
+#' @param x \code{repgrid} object
+#' @return \code{numeric}
+#'
+#' @export
+#' @keywords internal
+#' @author Mark Heckmann
+#'
+#' @examples \dontrun{
+#'
+#'      getNoOfConstructs(bell2010)
+#' }
+#'
+getNoOfConstructs <- function(x){
+  if (!inherits(x, "repgrid"))   # check if x is repgrid object
+    stop("object x and y must be of class 'repgrid'")
+  length(x@constructs)
+}
+
+
+#' Get number of elements
+#'
+#' @param x \code{repgrid} object
+#' @return \code{numeric} 
+#'
+#' @export
+#' @keywords internal
+#' @author Mark Heckmann
+#'
+#' @examples \dontrun{
+#'
+#'      getNoOfElements(bell2010)
+#' }
+#'
+getNoOfElements <- function(x){
+  if (!inherits(x, "repgrid")) 	# check if x is repgrid object
+    stop("object x and y must be of class 'repgrid'")
+  length(x@elements)
+}
+
+
+#' Set the scale range of a grid. 
+#'
+#' The scale must be known for certain 
+#' operations, e.g. to swap the construct poles. If the user construes
+#' a grid he should make sure that the scale range is set correctly.
+#'
+#' @param x       \code{repgrid} object.
+#' @param min     Minimal possible scale value for ratings.
+#' @param max     Maximal possible scale value for ratings.
+#' @param step    Steps the scales uses (not yet in use).
+#' @param ...     Not evaluated.
+#' 
+#' @return \code{repgrid} object
+#' @export
+#' @author Mark Heckmann
+#'
+#' @examples \dontrun{
+#'
+#'    x <- bell2010
+#'    x <- setScale(x, 0, 8)   # not set correctly
+#'    x
+#'    x <- setScale(x, 1, 7)   # set correctly
+#'    x
+#' }
+#'
+setScale <- function(x, min, max, step, ...){         # ... needes for makeRepgrid call
+  if(!inherits(x, "repgrid"))   						# check if x is repgrid object
+    stop("Object x must be of class 'repgrid'")
+  if (!missing(min)){
+    if (any(x@ratings < min, na.rm=TRUE))  # any rating value smaller than min?
+      stop("Some ratings are smaller than the min value you entered. ",
+           "The setting of the min value in the grid was not performed. ", 
+           "Please check the ratings or choose another min value.")
+    x@scale$min <- min
+  }
+  if (!missing(max)){
+    if (any(x@ratings > max, na.rm=TRUE))  # any rating value smaller than min?
+      stop("Some ratings are bigger than the max value you entered. ",
+           "The setting of the max value in the grid was not performed. ", 
+           "Please check the ratings or choose another max value.")
+    x@scale$max <- max
+  }
+  if (!missing(step))
+    x@scale$step <- step
+  x
+}
+# setScale(x, min=1, max=5, step=1)
+
+
+#' Get minimum and maximum scale value used in grid.
+#'
+#' The values are returned either as a vector or a list.
+#'
+#' @param x         \code{repgrid} object.
+#' @param output    Type of output object. 1= named vector, 2 = list.
+#' @return          Vector or list (depends on \code{output} containing 
+#'                  minimum and maximum scale value.
+#' @keywords        internal
+#' @export
+#' @author          Mark Heckmann
+#'
+getScale <- function(x, output=1){
+  if (!inherits(x, "repgrid")) 							# check if x is repgrid object
+    stop("Object x must be of class 'repgrid'")
+  smin <- x@scale$min
+  smax <- x@scale$max
+  if (output == 1)
+    res <- c(min=smin, max=smax) else 
+      if (output == 2)
+        res <- list(min=smin, max=smax)
+  res
+}
+
+
+### TODO
+#' setMeta
+#'
+#' set meta data of a grid (e.g. id, name of interview partner)
+#'
+#' @param x     repgrid object
+#' @param type  typemof grid in use (rating, ranked, implication)
+#' @param id    id of the interview
+#' @param name  name of the interview partner
+#' @return \code{repgrid} object
+#' @export
+#' @keywords internal
+#' @author   Mark Heckmann
+#'
+#' @examples \dontrun{
+#'
+#'    ####  TODO  ####
+#' }
+#'
+setMeta <- function(x, type, id, name){
+  if (!inherits(x, "repgrid"))   						# check if x is repgrid object
+    stop("Object x must be of class 'repgrid'")
+  if (!missing(type))                 # rating, rank or implication
+    x@meta$type <- type
+  if (!missing(name))
+    x@meta$id <- id
+  if (!missing(name))
+    x@meta$name <- name
+  x
+}
+#x <- setMeta(x, id=1, name="John Doe")
+
+
+#' Get midpoint of the grid rating scale
+#'
+#' @param x     \code{repgrid} object.
+#' @return      Midpoint of scale.
+#'
+#' @export
+#' @keywords    internal
+#' @author      Mark Heckmann
+#' @examples \dontrun{
+#'
+#'      getScaleMidpoint(bell2010)
+#'
+#' }
+#'
+getScaleMidpoint <- function(x){
+  if (!inherits(x, "repgrid"))   # check if x is repgrid object
+    stop("object x and y must be of class 'repgrid'")
+  (x@scale$max - x@scale$min)/2 + x@scale$min
+}
+
+
+#############################  CHANGE POSITION   ##############################
 
 #' Swap the position of two elements in a grid.
 #'
@@ -706,79 +916,8 @@ modifyElement <- function(x, pos, name=NA, abbreviation=NA, status=NA,
 #x <- modifyElement(x, pos=2, name="test")
 
 
-#' Set the scale range of a grid. 
-#'
-#' The scale must be known for certain 
-#' operations, e.g. to swap the construct poles. If the user construes
-#' a grid he should make sure that the scale range is set correctly.
-#'
-#' @param x       \code{repgrid} object.
-#' @param min     Minimal possible scale value for ratings.
-#' @param max     Maximal possible scale value for ratings.
-#' @param step    Steps the scales uses (not yet in use).
-#' @param ...     Not evaluated.
-#' 
-#' @return \code{repgrid} object
-#' @export
-#' @author Mark Heckmann
-#'
-#' @examples \dontrun{
-#'
-#'    x <- bell2010
-#'    x <- setScale(x, 0, 8)   # not set correctly
-#'    x
-#'    x <- setScale(x, 1, 7)   # set correctly
-#'    x
-#' }
-#'
-setScale <- function(x, min, max, step, ...){         # ... needes for makeRepgrid call
-  if(!inherits(x, "repgrid")) 							# check if x is repgrid object
-		stop("Object x must be of class 'repgrid'")
-  if (!missing(min)){
-    if (any(x@ratings < min, na.rm=TRUE))  # any rating value smaller than min?
-      stop("Some ratings are smaller than the min value you entered. ",
-            "The setting of the min value in the grid was not performed. ", 
-            "Please check the ratings or choose another min value.")
-    x@scale$min <- min
-  }
-  if (!missing(max)){
-    if (any(x@ratings > max, na.rm=TRUE))  # any rating value smaller than min?
-      stop("Some ratings are bigger than the max value you entered. ",
-            "The setting of the max value in the grid was not performed. ", 
-            "Please check the ratings or choose another max value.")
-    x@scale$max <- max
-  }
-  if (!missing(step))
-    x@scale$step <- step
-  x
-}
-# setScale(x, min=1, max=5, step=1)
 
 
-#' Get minimum and maximum scale value used in grid.
-#'
-#' The values are returned either as a vector or a list.
-#'
-#' @param x         \code{repgrid} object.
-#' @param output    Type of output object. 1= named vector, 2 = list.
-#' @return          Vector or list (depends on \code{output} containing 
-#'                  minimum and maximum scale value.
-#' @keywords        internal
-#' @export
-#' @author          Mark Heckmann
-#'
-getScale <- function(x, output=1){
-  if (!inherits(x, "repgrid")) 							# check if x is repgrid object
-	  stop("Object x must be of class 'repgrid'")
-	smin <- x@scale$min
-	smax <- x@scale$max
-	if (output == 1)
-	  res <- c(min=smin, max=smax) else 
-	if (output == 2)
-  	res <- list(min=smin, max=smax)
-  res
-}
-
  
 #' Print scale range information to the console.
 #'
@@ -828,37 +967,7 @@ setCoupled <- function(x, coupled=TRUE){
 
 
 
-### TODO
-#' setMeta
-#'
-#' set meta data of a grid (e.g. id, name of interview partner)
-#'
-#' @param x     repgrid object
-#' @param type  typemof grid in use (rating, ranked, implication)
-#' @param id    id of the interview
-#' @param name  name of the interview partner
-#' @return \code{repgrid} object
-#' @export
-#' @keywords internal
-#' @author   Mark Heckmann
-#'
-#' @examples \dontrun{
-#'
-#'    ####  TODO  ####
-#' }
-#'
-setMeta <- function(x, type, id, name){
-  if (!inherits(x, "repgrid")) 							# check if x is repgrid object
-		stop("Object x must be of class 'repgrid'")
-	if (!missing(type))                 # rating, rank or implication
-    x@meta$type <- type
-	if (!missing(name))
-    x@meta$id <- id
-	if (!missing(name))
-    x@meta$name <- name
-  x
-}
-#x <- setMeta(x, id=1, name="John Doe")
+
 
 
 #' showMeta
@@ -953,30 +1062,28 @@ makeRepgrid <- function(args){
 
 #' Concatenate the constructs of two grids. 
 #' 
-#' I.e. the
-#' constructs are combined to form one long grid.
+#' I.e. the constructs are combined to form one long grid.
 #' This function can be used in order to analyse multiple grids
 #' as one 'big grid' (eg. Slater, 1977, chap. 11).
 #'
 #' @param x       \code{repgrid} object
 #' @param y       \code{repgrid} object
-#' @param match   Constructs  will only be combined if they refer to the same
-#'                set of elements. If the elements are not the same or do not have the
-#'                same order no binding is done (if \code{test=TRUE}, default). 
+#' @param match   If the elements do not have the same order they
+#'                are reordered to match the element order of the first grid 'x'
+#'                (if \code{test=TRUE}, default). If set to FALSE an error occurs
+#'                if the element order is not identical in both grids.
+#' @param index   TODO. Logical (default \code{TRUE}). Whether to add an index at the end
+#'                of each construct name so it remains clear from which grid each 
+#'                construct came.                
 #'
 #' @return \code{repgrid} object
 #'
 #' @references  Slater, P. (1977). \emph{The measurement of intrapersonal space 
 #'              by grid technique}. London: Wiley.
 #'
-#' @note  Currently the grids are joined regardless if the column names are 
-#'        identical or not. Handle this function with care and make sure the 
-#'        elements of the grids are in the same order. In a future version
-#'        automatic testing of construct identity will take place.
-#'        TODO: Does not work well yet.
-#'
 #' @export
-#' @author  Mark Heckmann
+#' @keywords    internal
+#' @author      Mark Heckmann
 #'
 #' @examples \dontrun{
 #'
@@ -988,21 +1095,29 @@ makeRepgrid <- function(args){
 #'    bindConstructs(a, b, m=F)       # no binding
 #' }
 #'
-bindConstructs <- function(x, y, match=TRUE){
-  if (!inherits(x, "repgrid") & !inherits(y, "repgrid")) 	# check if x is repgrid object
-		stop("Object x and y must be of class 'repgrid'")
-	if (length(x@elements) != length(y@elements))           # check if grid has same number of columns
-	  stop("grids x and y do not have the same number of elements")
+bind <- function(x, y, match=TRUE, index=TRUE)
+{
+  if (!inherits(x, "repgrid") | !inherits(y, "repgrid")) 	# check if x is repgrid object
+		stop("object x and y must be of class 'repgrid'", call. = FALSE)
+	if (getNoOfElements(x) != getNoOfElements(y))           # check if grid has same number of columns
+	  stop("grids must have the same number of elements", call. = FALSE)
+  if (any(getScale(x) != getScale(y)))
+    stop("concatenated grids must have identical scale ranges", call. = FALSE)
   names.x <- getElementNames(x)
   names.y <- getElementNames(y)
   if (!all(names.x %in% names.y))
-    stop("elements in grid x and y do not have the same set of elements")
+    stop("grids must have the same set of elements", call. = FALSE)
+  
   if (match & !identical(names.x, names.y)){  
-    y <- y[ ,orderByString(names.x, names.y)]
+    #y <- y[ ,orderByString(names.x, names.y)]
+    reorder.index.y <- match(names.x, names.y)  # reorder elements of y by elements of x
+    y <- y[ , reorder.index.y]
   } else if (!match & !identical(names.x, names.y)){
     stop("elements are the same but dop not have the same order.",
          "choose reorder=TRUE if you want to allow matching of element positions")
   }
+  x <- x[ , ]  # to counteract that decoupled arrays are dropped when using [, ]
+  y <- y[ , ]
   res <- x
   res@ratings <- abind(x@ratings[ , , , drop=FALSE],  
                        y@ratings[ , , , drop=FALSE], along=1)
@@ -1011,6 +1126,92 @@ bindConstructs <- function(x, y, match=TRUE){
 }
 
 
+#' Concatenate the constructs of two or more grids. 
+#' 
+#' I.e. the constructs are combined to form one long grid.
+#' The girds must have the same set of elements and an identical 
+#' scale range. The order of the elements may differ.
+#' 
+#' This function can be used in order to analyse multiple grids
+#' as one 'big grid' (eg. Slater, 1977, chap. 11).
+#'
+#' @param ...     One or more repgrid objects or a list containing
+#'                \code{repgrid} object.
+#' @param index   TODO. Logical (default \code{TRUE}). Whether to add an index at the end
+#'                of each construct name so it remains clear from which grid each 
+#'                construct came.                
+#'
+#' @return        \code{repgrid} object with concatenated constructs.
+#'
+#' @references  Slater, P. (1977). \emph{The measurement of intrapersonal space 
+#'              by grid technique}. London: Wiley.
+#'
+#' @export
+#' @author  Mark Heckmann
+#'
+#' @examples 
+#'
+#'  a <- randomGrid()
+#'  b <- randomGrid()
+#'  b@@elements <- rev(a@@elements)   # reverse elements
+#'  bindConstructs(a, b)
+#'  bindConstructs(a, b, a)
+#'  
+#'  # using lists of repgrid objects 
+#'  bindConstructs(a, list(a, b))
+#'
+bindConstructs <- function(..., index=FALSE)
+{
+  dots <- list(...) 
+  dots <- unlist(dots)        # in case list of repgrid objects are supplied
+  is.grid <- sapply(dots, function(x) inherits(x, "repgrid"))
+  Reduce("bind", dots[is.grid])
+}
+
+
+#' Concatenate repgrid objects.
+#' 
+#' Simple concatenation of repgrid objects or list containing
+#' repgrid objects using the '+' operator.
+#'
+#' Methods for \code{"+"} function. 
+#'
+#' @aliases +,repgrid,repgrid-method
+#' @docType methods
+#' @author Mark heckmann
+#' @rdname ops-methods
+#' @include repgrid.r
+#' @export
+#' @examples 
+#' 
+#' x <- bell2010
+#' x + x
+#' x + list(x,x)
+#' list(x,x) + x 
+#'
+setMethod("+", signature(e1="repgrid", e2="repgrid"),
+    function(e1, e2) bindConstructs(e1, e2))
+
+
+#' @docType methods
+#' @aliases +,list,repgrid-method
+#' @rdname ops-methods
+#' 
+setMethod("+", signature(e1="list", e2="repgrid"),
+    function(e1, e2) {          
+      bindConstructs(e1, e2)
+    })
+
+
+#' @docType methods
+#' @aliases +,repgrid,list-method
+#' @rdname ops-methods
+#'
+setMethod("+", signature(e1="repgrid", e2="list"),
+    function(e1, e2) {          
+      bindConstructs(e1, e2)
+    })
+
 
 #' Join the constructs of a grid with the same reversed constructs.
 #'
@@ -1033,49 +1234,6 @@ doubleEntry <- function(x){
 }
 
 
-
-#' get number of constructs
-#'
-#' @param x \code{repgrid} object
-#' @return \code{numeric}
-#'
-#' @export
-#' @keywords internal
-#' @author Mark Heckmann
-#'
-#' @examples \dontrun{
-#'
-#'      getNoOfConstructs(bell2010)
-#' }
-#'
-getNoOfConstructs <- function(x){
-  if (!inherits(x, "repgrid")) 	# check if x is repgrid object
-		stop("object x and y must be of class 'repgrid'")
-	length(x@constructs)
-}
-
-
-#' get number of elements
-#'
-#' @param x \code{repgrid} object
-#' @return \code{numeric} 
-#'
-#' @export
-#' @keywords internal
-#' @author Mark Heckmann
-#'
-#' @examples \dontrun{
-#'
-#'      getNoOfElements(bell2010)
-#' }
-#'
-getNoOfElements <- function(x){
-  if (!inherits(x, "repgrid")) 	# check if x is repgrid object
-		stop("object x and y must be of class 'repgrid'")
-	length(x@elements)
-}
-
-
 #' Return size of a grid. 
 #'
 #' \code{dim} returns a numeric vector of length
@@ -1102,66 +1260,6 @@ dim.repgrid <- function(x){
 }
 
 
-#' Get midpoint of the grid rating scale
-#'
-#' @param x     \code{repgrid} object.
-#' @return      Midpoint of scale.
-#'
-#' @export
-#' @keywords    internal
-#' @author      Mark Heckmann
-#' @examples \dontrun{
-#'
-#'      getScaleMidpoint(bell2010)
-#'
-#' }
-#'
-getScaleMidpoint <- function(x){
-  if (!inherits(x, "repgrid")) 	# check if x is repgrid object
-		stop("object x and y must be of class 'repgrid'")
-	(x@scale$max - x@scale$min)/2 + x@scale$min
-}
-
-
-#' get rating layer
-#'
-#' @param   x       \code{repgrid} object.
-#' @param   layer   layer to be returned.
-#' @param   names   extract row and columns names (constructs and elements).
-#' @param trim      the number of characters a row or column name is trimmed to 
-#'                  (default is \code{10}). If \code{NA} no trimming is done. Trimming
-#'                  simply saves space when displaying the output.
-#' @return          a \code{matrix} 
-#'
-#' @export
-#' @keywords internal
-#' @author Mark Heckmann
-#'
-#' @examples \dontrun{
-#'
-#'      getRatingLayer(bell2010)
-#' }
-#'
-getRatingLayer <- function(x, layer=1, names=TRUE, trim=10){
-  scores <- x@ratings[ , , layer, drop=FALSE]       # select layer
-  rm <- apply(scores, 2 , I)                        # convert array to matrix 
-  if (names) {
-    cnames.l <- getConstructNames(x)[ ,1]
-    cnames.r <- getConstructNames(x)[ ,2]
-    enames <- getElementNames(x)
-    if (!is.na(trim)){                              # trim names if prompted
-       cnames.l <- substr(cnames.l, 1, trim)
-       cnames.r <- substr(cnames.r, 1, trim)
-       enames <- substr(enames, 1, trim)
-    }                             
-    rownames(rm) <- paste(cnames.l, cnames.r, sep=" - ") 
-    colnames(rm) <- enames   
-  }
-  rm
-}
-
-
-
 # set status coupled equals TRIE or FALSE. Depending on the setting,
 # certain functions will work differently
 #
@@ -1192,3 +1290,5 @@ decouple <- function(x){
 
 
 
+
+
